@@ -20,6 +20,8 @@
  */
 #include "kmessagebox_p.h"
 
+#include "loggingcategory.h"
+
 #include <QCoreApplication>
 #include <QDebug>
 #include <QPluginLoader>
@@ -50,7 +52,7 @@ public:
         }
     }
 
-    bool shouldBeShownYesNo(const QString &dontShowAgainName, KMessageBox::ButtonCode &result) Q_DECL_OVERRIDE
+    bool shouldBeShownYesNo(const QString &dontShowAgainName, KMessageBox::ButtonCode &result) override
     {
         KMessageBox::ButtonCode code = m_saved.value(dontShowAgainName, KMessageBox::ButtonCode(0));
         if (code == KMessageBox::Yes || code == KMessageBox::No) {
@@ -59,30 +61,30 @@ public:
         }
         return true;
     }
-    bool shouldBeShownContinue(const QString &dontShowAgainName) Q_DECL_OVERRIDE
+    bool shouldBeShownContinue(const QString &dontShowAgainName) override
     {
         KMessageBox::ButtonCode code = m_saved.value(dontShowAgainName, KMessageBox::Yes);
         return code == KMessageBox::Yes;
     }
-    void saveDontShowAgainYesNo(const QString &dontShowAgainName, KMessageBox::ButtonCode result) Q_DECL_OVERRIDE
+    void saveDontShowAgainYesNo(const QString &dontShowAgainName, KMessageBox::ButtonCode result) override
     {
         m_saved[dontShowAgainName] = result;
     }
-    void saveDontShowAgainContinue(const QString &dontShowAgainName) Q_DECL_OVERRIDE
+    void saveDontShowAgainContinue(const QString &dontShowAgainName) override
     {
         m_saved[dontShowAgainName] = KMessageBox::No;
     }
-    void enableAllMessages() Q_DECL_OVERRIDE
+    void enableAllMessages() override
     {
         m_saved.clear();
     }
-    void enableMessage(const QString &dontShowAgainName) Q_DECL_OVERRIDE
+    void enableMessage(const QString &dontShowAgainName) override
     {
         m_saved.remove(dontShowAgainName);
     }
-    void setConfig(KConfig *) Q_DECL_OVERRIDE
+    void setConfig(KConfig *) override
     {
-        qWarning() << "Using QSettings based KMessageBoxDontAskAgainInterface. KMessageBox::setDontShowAgainConfig ignored";
+        qCWarning(KWidgetsAddonsLog) << "Using QSettings based KMessageBoxDontAskAgainInterface. KMessageBox::setDontShowAgainConfig ignored";
     }
 
 private:
@@ -93,14 +95,14 @@ private:
 class KMessageBoxNotifyDummy : public KMessageBoxNotifyInterface
 {
 public:
-    void sendNotification(QMessageBox::Icon /*notificationType*/, const QString &/*message*/, QWidget * /*parent*/) Q_DECL_OVERRIDE {}
+    void sendNotification(QMessageBox::Icon /*notificationType*/, const QString &/*message*/, QWidget * /*parent*/) override {}
 };
 
 Q_GLOBAL_STATIC(KMessageBoxDontAskAgainQSettingsStorage, s_defaultDontAskAgainInterface)
 Q_GLOBAL_STATIC(KMessageBoxNotifyDummy, s_defaultNotifyInterface)
 
-static KMessageBoxDontAskAgainInterface *s_dontAskAgainInterface = 0;
-static KMessageBoxNotifyInterface *s_notifyInterface = 0;
+static KMessageBoxDontAskAgainInterface *s_dontAskAgainInterface = nullptr;
+static KMessageBoxNotifyInterface *s_notifyInterface = nullptr;
 
 static void loadKMessageBoxPlugin()
 {
@@ -141,13 +143,13 @@ KMessageBoxNotifyInterface *notifyInterface()
 
 void setDontShowAgainInterface(KMessageBoxDontAskAgainInterface *dontAskAgainInterface)
 {
-    Q_ASSERT(dontAskAgainInterface != 0);
+    Q_ASSERT(dontAskAgainInterface != nullptr);
     s_dontAskAgainInterface = dontAskAgainInterface;
 }
 
 void setNotifyInterface(KMessageBoxNotifyInterface *notifyInterface)
 {
-    Q_ASSERT(notifyInterface != 0);
+    Q_ASSERT(notifyInterface != nullptr);
     s_notifyInterface = notifyInterface;
 }
 
